==> jc-1.4.0.tar.gz: polyglot/ast/Assign.h <==
// public abstract interface polyglot.ast.Assign

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 528a1e885893fafb polyglot_ast_Assign

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Assign_H_
#define _JC_polyglot_ast_Assign_H_

// Typedefs
typedef struct _jc_polyglot_ast_Assign$fields_struct	_jc_polyglot_ast_Assign$fields_struct;
typedef const struct _jc_polyglot_ast_Assign$vtype	_jc_polyglot_ast_Assign$vtype;

// Class fields structure
struct _jc_polyglot_ast_Assign$fields_struct {
	struct _jc_polyglot_ast_Assign__24Operator$object	*ADD__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*ASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fAND__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fOR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fXOR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*DIV__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*MOD__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*MUL__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SHL__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SHR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SUB__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*USHR__5fASSIGN;
};
extern _jc_polyglot_ast_Assign$fields_struct _jc_polyglot_ast_Assign$class_fields;

// Static methods
extern void _jc_polyglot_ast_Assign$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Vtype
struct _jc_polyglot_ast_Assign$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Assign$vtype _jc_polyglot_ast_Assign$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Assign, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Assign$class_object;

#endif	/* _JC_polyglot_ast_Assign_H_ */

==> jc-1.4.6.tar.gz: polyglot/ast/Assign.h <==
// public abstract interface polyglot.ast.Assign

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 528a1e885893fafb polyglot_ast_Assign

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ast_Assign_H_
#define _JC_polyglot_ast_Assign_H_

// Typedefs
typedef struct _jc_polyglot_ast_Assign$fields_struct	_jc_polyglot_ast_Assign$fields_struct;
typedef const struct _jc_polyglot_ast_Assign$vtype	_jc_polyglot_ast_Assign$vtype;

// Class fields structure
struct _jc_polyglot_ast_Assign$fields_struct {
	struct _jc_polyglot_ast_Assign__24Operator$object	*ADD__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*ASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fAND__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fOR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*BIT__5fXOR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*DIV__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*MOD__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*MUL__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SHL__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SHR__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*SUB__5fASSIGN;
	struct _jc_polyglot_ast_Assign__24Operator$object	*USHR__5fASSIGN;
};
extern _jc_polyglot_ast_Assign$fields_struct _jc_polyglot_ast_Assign$class_fields;

// Static methods
extern void _jc_polyglot_ast_Assign$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Vtype
struct _jc_polyglot_ast_Assign$vtype {
	_jc_type			type;
};

// Type structure
extern _jc_polyglot_ast_Assign$vtype _jc_polyglot_ast_Assign$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ast_Assign, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ast_Assign$class_object;

#endif	/* _JC_polyglot_ast_Assign_H_ */
